@@ -31,9 +31,9 @@ from calculate.lib.utils.files import readFile, listDirectory, process, pathJoin
 
 from calculate.lib.configparser import ConfigParser
 from calculate.lib.cl_lang import setLocalTranslate
-from calculate.lib.utils.text import simplify_profiles
+from calculate.lib.utils.text import simplify_profiles, _u8
 from calculate.lib.utils.git import Git, GitError
-from calculate.lib.utils.portage import Layman
+from calculate.lib.utils.portage import ReposConf
 from ..profile import (RepositoryStorageSet, DEFAULT_BRANCH,
                        LocalStorage, ProfileRepository, CacheStorage)
 
@@ -164,30 +164,26 @@ class VariableClUpdateRepUrl(Variable):
     value = []
 
 
-class VariableClUpdateLaymanConfig(ReadonlyVariable):
-    """
-    Объект конфига layman
-    """
-    type = "object"
-
-    def get(self):
-        chroot = self.Get('cl_chroot_path')
-        cp = ConfigParser()
-        cp.read(path.join(chroot, 'etc/layman/layman.cfg'))
-        return cp
-
-
 class VariableClUpdateLaymanStorage(Variable):
     """
-    Путь к репозиториям layman
+    Путь к репозиториям
     """
     param_name = "storage"
     fallback_value = "var/lib/layman"
 
     def get(self):
-        cp = self.Get('cl_update_layman_config')
-        res = cp.get('MAIN', self.param_name, fallback=self.fallback_value)
-        return pathJoin(self.Get('cl_chroot_path'), res)
+        return pathJoin(self.Get('cl_chroot_path'), self.fallback_value)
+
+
+class VariableClUpdateReposStorage(Variable):
+    """
+    Путь к репозиториям
+    """
+    param_name = "storage"
+    fallback_value = "var/db/repos"
+
+    def get(self):
+        return pathJoin(self.Get('cl_chroot_path'), self.fallback_value)
 
 
 class VariableClUpdateRepPath(ReadonlyVariable):
@@ -199,7 +195,7 @@ class VariableClUpdateRepPath(ReadonlyVariable):
                'gentoo': 'usr/portage'}
 
     def get(self):
-        repPath = self.Get('cl_update_layman_storage')
+        repPath = self.Get('cl_update_repos_storage')
         chroot_path = self.Get('cl_chroot_path')
 
         def generatePaths(names):
@@ -569,21 +565,15 @@ class VariableClUpdateOtherRepData(ReadonlyTableVariable):
     source = ['cl_update_other_rep_name',
               'cl_update_other_rep_path']
 
-    portdir_overlay = "main.cl_portdir_overlay"
-
     def generator(self):
         repNames = self.Get('update.cl_update_rep_name')
         chroot_path = self.Get('cl_chroot_path')
-        layman = Layman(self.Get('update.cl_update_layman_installed'),
-                        self.Get('update.cl_update_layman_make'),
-                        self.Get('update.cl_update_layman_conf'),
-                        prefix=chroot_path)
-        layman_overlays = layman.get_installed()
-        for rpath in self.Get(self.portdir_overlay):
-            repo_file = path.join(rpath, "profiles/repo_name")
-            rname = readFile(repo_file).strip() or path.basename(rpath)
-            if rname in layman_overlays and rname not in repNames:
-                yield (rname, rpath)
+        reposconf = ReposConf(
+            self.Get('update.cl_update_reposconf'),
+            self.Get('update.cl_update_reposconf_dir'),
+            prefix=chroot_path)
+        for rname, rpath in reposconf.get_other_repositories():
+            yield (_u8(rname), pathJoin(chroot_path, _u8(rpath)))
 
     def get(self, hr=HumanReadable.No):
         return list(self.generator())
@@ -607,28 +597,21 @@ class VariableClUpdateOtherRepPath(FieldValue, ReadonlyVariable):
     column = 1
 
 
-class VariableClUpdateLaymanInstalled(VariableClUpdateLaymanStorage):
+class VariableClUpdateReposconfDir(ReadonlyVariable):
     """
-    Путь до файла layman installed.xml
+    Директорий с файлами, описывающими репозитории
     """
-    param_name = "installed"
-    fallback_value = "var/lib/layman/installed.xml"
 
+    def get(self):
+        chroot = self.Get('cl_chroot_path')
+        return path.join(chroot, '/etc/portage/repos.conf')
 
-class VariableClUpdateLaymanMake(VariableClUpdateLaymanStorage):
+class VariableClUpdateReposconf(ReadonlyVariable):
     """
-    Путь до файла make.conf изменяемого layman`ом
+    Путь конфигурационного файла repos.conf, содержащего Calculate репозитории
     """
-    param_name = "make_conf"
-    fallback_value = "var/lib/layman/make.conf"
 
-
-class VariableClUpdateLaymanConf(VariableClUpdateLaymanStorage):
-    """
-    Путь до конфигурационного файла репозиториев для layman
-    """
-    param_name = "repos_conf"
-    fallback_value = "etc/portage/repos.conf/layman.conf"
+    value_format = "{update.cl_update_reposconf_dir}/calculate.conf"
 
 
 class VariableClUpdatePretendSet(Variable):
@@ -687,7 +670,7 @@ class VariableClUpdateProfileStorage(ReadonlyVariable):
     def get(self):
         git = self.Get('cl_update_git')
         return RepositoryStorageSet(
-            LocalStorage(git, '/var/lib/layman'),
+            LocalStorage(git, '/var/db/repos'),
             CacheStorage(git, '/var/calculate/tmp/update'))
 
 
@@ -1288,14 +1271,16 @@ class DataVarsUpdateProfile(SimpleDataVars):
             env.VariableClFeatures(),
             env.VariableClMakeProfile(),
             env.VariableClEbuildPhase(),
+            VariableClUpdateReposStorage(section="update"),
+            VariableClUpdateLaymanStorage(section="update"),
+            VariableClUpdateReposconf(section="update"),
+            VariableClUpdateReposconfDir(section="update"),
             VariableClUpdateRepData(section="update"),
             VariableClUpdateRepPath(section="update"),
             VariableClUpdateRepRev(section="update"),
             VariableClUpdateBranch(section="update"),
             VariableClUpdateBranchName(section="update"),
             VariableClUpdateUsetagSet(section="update"),
-            VariableClUpdateLaymanConfig(section="update"),
-            VariableClUpdateLaymanStorage(section="update"),
             VariableClUpdateRepName(section="update"),
             VariableClUpdateRep(section="update"),
             VariableClUpdateRepUrl(section="update"),
